package physapps.thermodynamics;

import javax.swing.*;
import java.awt.*;
import physbeans.views.*;
import physbeans.model.*;
import physbeans.phys.*;
import physbeans.math.*;
import physbeans.inout.*;

/**
 * template for simulation applets<br>
 * contains an input, object and output panel
 */
public class CarnotCycle extends PhysBeansApplet {
  
  static public void main(String[] args) {
    startApp(new CarnotCycle(), 560, 470);
  }
  
  /** Creates new form Simulation */
  public void init() {
    setLocale();
    initComponents();
  }
  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
  private void initComponents() {
    cyclicProcess1 = new physbeans.phys.CyclicProcess();
    perfectGas1 = new physbeans.phys.PerfectGas();
    multiplexer1 = new physbeans.func.Multiplexer();
    multiplexer2 = new physbeans.func.Multiplexer();
    multiplexer3 = new physbeans.func.Multiplexer();
    cylinderView1 = new physbeans.views.CylinderView();
    jPanel1 = new javax.swing.JPanel();
    jPanel2 = new javax.swing.JPanel();
    objectPanel1 = new physbeans.inout.ObjectPanel();
    layeredScreen1 = new physbeans.inout.LayeredScreen();
    numericTextField1 = new physbeans.inout.NumericTextField();
    outputPanel1 = new physbeans.inout.OutputPanel();
    xYScope1 = new physbeans.inout.XYScope();
    inputPanel1 = new physbeans.inout.InputPanel();
    timer1 = new physbeans.inout.Timer();
    textSlider1 = new physbeans.inout.TextSlider();
    textSlider2 = new physbeans.inout.TextSlider();
    textSlider3 = new physbeans.inout.TextSlider();
    textSlider4 = new physbeans.inout.TextSlider();

    cyclicProcess1.setNSteps(new int[]{50,50,50,50});
    cyclicProcess1.setPoints(DVector.valueOf("[1.435,2.87,9.055]"));
    cyclicProcess1.setPolytropicExponents(DVector.valueOf("[1.0,1.4,1.0,1.4]"));
    cyclicProcess1.setStartPressure(2000000.0);
    cyclicProcess1.setSystem(perfectGas1);
    perfectGas1.setMass(10.0);
    perfectGas1.addTriggerListener(new physbeans.event.TriggerListener() {
      public void sourceChanged(physbeans.event.TriggerEvent evt) {
        perfectGas1SourceChanged(evt);
        perfectGas1SourceChanged1(evt);
        perfectGas1SourceChanged2(evt);
      }
    });

    multiplexer1.setInputLength(3);
    multiplexer1.setCollectInput(false);
    multiplexer1.addVectorListener(new physbeans.event.VectorListener() {
      public void valueChanged(physbeans.event.VectorEvent evt) {
        multiplexer1ValueChanged(evt);
      }
    });

    multiplexer2.setAutoTriggered(false);
    multiplexer2.addVectorListener(new physbeans.event.VectorListener() {
      public void valueChanged(physbeans.event.VectorEvent evt) {
        multiplexer2ValueChanged(evt);
      }
    });

    multiplexer3.addVectorListener(new physbeans.event.VectorListener() {
      public void valueChanged(physbeans.event.VectorEvent evt) {
        multiplexer3ValueChanged(evt);
      }
    });

    cylinderView1.setTMax(1500.0);
    cylinderView1.setTMin(300.0);
    cylinderView1.setInitialValues(DVector.valueOf("[1.435,1000.0]"));
    cylinderView1.setMaxVolume(10.0);
    cylinderView1.setPistonDiameter(0.03);
    cylinderView1.addTriggerListener(new physbeans.event.TriggerListener() {
      public void sourceChanged(physbeans.event.TriggerEvent evt) {
        cylinderView1SourceChanged(evt);
        cylinderView1SourceChanged1(evt);
      }
    });

    jPanel1.setLayout(new java.awt.BorderLayout());

    jPanel1.setBorder(javax.swing.BorderFactory.createCompoundBorder(javax.swing.BorderFactory.createBevelBorder(javax.swing.border.BevelBorder.RAISED), javax.swing.BorderFactory.createBevelBorder(javax.swing.border.BevelBorder.LOWERED)));
    jPanel1.setFont(standardFont);
    jPanel2.setLayout(new javax.swing.BoxLayout(jPanel2, javax.swing.BoxLayout.Y_AXIS));

    jPanel2.setFont(standardFont);
    layeredScreen1.setBordered(true);
    layeredScreen1.setMaxX(1.2);
    layeredScreen1.setMaxY(0.8);
    layeredScreen1.setMinX(-0.2);
    layeredScreen1.setMinY(-0.8);
    layeredScreen1.setBackground(java.awt.Color.white);
    layeredScreen1.setOpaque(true);
    objectPanel1.add(layeredScreen1, java.awt.BorderLayout.CENTER);

    numericTextField1.setDescription("T =");
    numericTextField1.setEditable(false);
    numericTextField1.setPrecision(4);
    numericTextField1.setUnit("K");
    objectPanel1.add(numericTextField1, java.awt.BorderLayout.SOUTH);

    jPanel2.add(objectPanel1);

    xYScope1.setBufferSize(5000);
    xYScope1.setDotSize(6);
    xYScope1.setMaxX(11.0);
    xYScope1.setMaxY(2600000.0);
    xYScope1.setMinX(0.0);
    xYScope1.setMinY(0.0);
    xYScope1.setPositionLabel(java.util.ResourceBundle.getBundle("physapps.thermodynamics.CarnotCycle", currentLocale).getString("osciPosition"));
    xYScope1.setScaleLabel(java.util.ResourceBundle.getBundle("physapps.thermodynamics.CarnotCycle", currentLocale).getString("osciScale"));
    xYScope1.setShowMarker(true);
    outputPanel1.add(xYScope1);

    jPanel2.add(outputPanel1);

    jPanel1.add(jPanel2, java.awt.BorderLayout.CENTER);

    inputPanel1.setLayout(new javax.swing.BoxLayout(inputPanel1, javax.swing.BoxLayout.Y_AXIS));

    timer1.setDelay(20L);
    timer1.setExplanation(java.util.ResourceBundle.getBundle("physapps.thermodynamics.CarnotCycle", currentLocale).getString("timerLabel"));
    timer1.addTimerListener(new physbeans.event.TimerListener() {
      public void nextStep(physbeans.event.NextStepEvent evt) {
        timer1NextStep(evt);
      }
      public void restart(physbeans.event.RestartEvent evt) {
        timer1Restart(evt);
        timer1Restart1(evt);
      }
    });

    inputPanel1.add(timer1);

    textSlider1.setDescription("p1 =");
    textSlider1.setModel(new BoundedRealModel(300000.0,2000000.0,2500000.0));
    textSlider1.setUnit("Pa");
    textSlider1.addPropertyChangeListener(new java.beans.PropertyChangeListener() {
      public void propertyChange(java.beans.PropertyChangeEvent evt) {
        textSlider1PropertyChange(evt);
      }
    });

    inputPanel1.add(textSlider1);

    textSlider2.setDescription("V1 =");
    textSlider2.setModel(new BoundedRealModel(0.1,1.435,10.0));
    textSlider2.setUnit("m\u00b3");
    textSlider2.addPropertyChangeListener(new java.beans.PropertyChangeListener() {
      public void propertyChange(java.beans.PropertyChangeEvent evt) {
        textSlider2PropertyChange(evt);
      }
    });

    inputPanel1.add(textSlider2);

    textSlider3.setDescription("V2 =");
    textSlider3.setModel(new BoundedRealModel(0.1,4.25,10.0));
    textSlider3.setUnit("m\u00b3");
    textSlider3.addPropertyChangeListener(new java.beans.PropertyChangeListener() {
      public void propertyChange(java.beans.PropertyChangeEvent evt) {
        textSlider3PropertyChange(evt);
      }
    });

    inputPanel1.add(textSlider3);

    textSlider4.setDescription("V3 =");
    textSlider4.setModel(new BoundedRealModel(0.1,9.055,10.0));
    textSlider4.setUnit("m\u00b3");
    textSlider4.addPropertyChangeListener(new java.beans.PropertyChangeListener() {
      public void propertyChange(java.beans.PropertyChangeEvent evt) {
        textSlider4PropertyChange(evt);
      }
    });

    inputPanel1.add(textSlider4);

    jPanel1.add(inputPanel1, java.awt.BorderLayout.EAST);

    getContentPane().add(jPanel1, java.awt.BorderLayout.CENTER);

  }// </editor-fold>//GEN-END:initComponents

  private void cylinderView1SourceChanged1(physbeans.event.TriggerEvent evt) {//GEN-FIRST:event_cylinderView1SourceChanged1
    layeredScreen1.addView(cylinderView1);
  }//GEN-LAST:event_cylinderView1SourceChanged1

  private void cylinderView1SourceChanged(physbeans.event.TriggerEvent evt) {//GEN-FIRST:event_cylinderView1SourceChanged
    layeredScreen1.addView(cylinderView1);
  }//GEN-LAST:event_cylinderView1SourceChanged
  
  private void multiplexer3ValueChanged(physbeans.event.VectorEvent evt) {//GEN-FIRST:event_multiplexer3ValueChanged
    cylinderView1.setModel(multiplexer3.getOutputVector());
  }//GEN-LAST:event_multiplexer3ValueChanged
  
  private void perfectGas1SourceChanged2(physbeans.event.TriggerEvent evt) {//GEN-FIRST:event_perfectGas1SourceChanged2
    numericTextField1.setValue(perfectGas1.getTemperature());
  }//GEN-LAST:event_perfectGas1SourceChanged2
  
  private void perfectGas1SourceChanged1(physbeans.event.TriggerEvent evt) {//GEN-FIRST:event_perfectGas1SourceChanged1
    multiplexer3.setInputValues(0, perfectGas1.getVolume());
    multiplexer3.setInputValues(1, perfectGas1.getTemperature());
  }//GEN-LAST:event_perfectGas1SourceChanged1
  
  private void multiplexer2ValueChanged(physbeans.event.VectorEvent evt) {//GEN-FIRST:event_multiplexer2ValueChanged
    xYScope1.setInputVector(multiplexer2.getOutputVector());
  }//GEN-LAST:event_multiplexer2ValueChanged
  
  private void perfectGas1SourceChanged(physbeans.event.TriggerEvent evt) {//GEN-FIRST:event_perfectGas1SourceChanged
    multiplexer2.setInputValues(0, perfectGas1.getVolume());
    multiplexer2.setInputValues(1, perfectGas1.getPressure());
  }//GEN-LAST:event_perfectGas1SourceChanged
  
  private void multiplexer1ValueChanged(physbeans.event.VectorEvent evt) {//GEN-FIRST:event_multiplexer1ValueChanged
    cyclicProcess1.setPoints(multiplexer1.getOutputVector());
  }//GEN-LAST:event_multiplexer1ValueChanged
  
  private void textSlider4PropertyChange(java.beans.PropertyChangeEvent evt) {//GEN-FIRST:event_textSlider4PropertyChange
    multiplexer1.setInputValues(2, textSlider4.getValue());
  }//GEN-LAST:event_textSlider4PropertyChange
  
  private void textSlider3PropertyChange(java.beans.PropertyChangeEvent evt) {//GEN-FIRST:event_textSlider3PropertyChange
    multiplexer1.setInputValues(1, textSlider3.getValue());
  }//GEN-LAST:event_textSlider3PropertyChange
  
  private void textSlider2PropertyChange(java.beans.PropertyChangeEvent evt) {//GEN-FIRST:event_textSlider2PropertyChange
    multiplexer1.setInputValues(0, textSlider2.getValue());
  }//GEN-LAST:event_textSlider2PropertyChange
  
  private void textSlider1PropertyChange(java.beans.PropertyChangeEvent evt) {//GEN-FIRST:event_textSlider1PropertyChange
    cyclicProcess1.setStartPressure(textSlider1.getValue());
  }//GEN-LAST:event_textSlider1PropertyChange
  
  private void timer1Restart1(physbeans.event.RestartEvent evt) {//GEN-FIRST:event_timer1Restart1
    xYScope1.restart();
  }//GEN-LAST:event_timer1Restart1
  
  private void timer1Restart(physbeans.event.RestartEvent evt) {//GEN-FIRST:event_timer1Restart
    cyclicProcess1.restart();
  }//GEN-LAST:event_timer1Restart
  
  private void timer1NextStep(physbeans.event.NextStepEvent evt) {//GEN-FIRST:event_timer1NextStep
    cyclicProcess1.nextStep();
    multiplexer2.trigger();
  }//GEN-LAST:event_timer1NextStep
  
  
  // Variables declaration - do not modify//GEN-BEGIN:variables
  protected physbeans.phys.CyclicProcess cyclicProcess1;
  protected physbeans.views.CylinderView cylinderView1;
  protected physbeans.inout.InputPanel inputPanel1;
  protected javax.swing.JPanel jPanel1;
  protected javax.swing.JPanel jPanel2;
  protected physbeans.inout.LayeredScreen layeredScreen1;
  protected physbeans.func.Multiplexer multiplexer1;
  protected physbeans.func.Multiplexer multiplexer2;
  protected physbeans.func.Multiplexer multiplexer3;
  protected physbeans.inout.NumericTextField numericTextField1;
  protected physbeans.inout.ObjectPanel objectPanel1;
  protected physbeans.inout.OutputPanel outputPanel1;
  protected physbeans.phys.PerfectGas perfectGas1;
  protected physbeans.inout.TextSlider textSlider1;
  protected physbeans.inout.TextSlider textSlider2;
  protected physbeans.inout.TextSlider textSlider3;
  protected physbeans.inout.TextSlider textSlider4;
  protected physbeans.inout.Timer timer1;
  protected physbeans.inout.XYScope xYScope1;
  // End of variables declaration//GEN-END:variables
  
}
